==> openjdk-11_11.0.25~5ea.orig.tar.xz: openjdk-11-11.0.25~5ea/test/jdk/sun/security/tools/jarsigner/NewSize7.java <==
/*
 * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 6561126
 * @summary keytool should use larger default keysize for keypairs
 * @library /test/lib
 */

import jdk.test.lib.Asserts;
import jdk.test.lib.SecurityTools;
import jdk.test.lib.util.JarUtils;

import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.jar.JarFile;
import java.util.jar.Manifest;

public class NewSize7 {
    public static void main(String[] args) throws Exception {
        String common = "-storepass changeit -keypass changeit -keystore ks ";
        SecurityTools.keytool(common
                + "-keyalg rsa -genkeypair -alias me -dname CN=Me");
        Files.write(Path.of("ns7.txt"), new byte[0]);
        JarUtils.createJarFile(Path.of("ns7.jar"), Path.of("."),
                Path.of("ns7.txt"));
        SecurityTools.jarsigner(common + "ns7.jar me");

        try (JarFile jf = new JarFile("ns7.jar")) {
            try (InputStream is = jf.getInputStream(
                    jf.getEntry("META-INF/MANIFEST.MF"))) {
                Asserts.assertTrue(new Manifest(is).getAttributes("ns7.txt")
                        .keySet().stream()
                        .anyMatch(s -> s.toString().contains("SHA-256")));
            }
            try (InputStream is = jf.getInputStream(
                    jf.getEntry("META-INF/ME.SF"))) {
                Asserts.assertTrue(new Manifest(is).getAttributes("ns7.txt")
                        .keySet().stream()
                        .anyMatch(s -> s.toString().contains("SHA-256")));
            }
        }
    }
}

==> openjdk-25_25~10ea.orig.tar.xz: openjdk-25-25~10ea/test/jdk/sun/security/tools/jarsigner/NewSize7.java <==
/*
 * Copyright (c) 2009, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 6561126 8267319
 * @modules jdk.jartool/jdk.security.jarsigner
 * @summary keytool should use larger default keysize for keypairs
 * @library /test/lib
 */

import jdk.test.lib.Asserts;
import jdk.test.lib.SecurityTools;
import jdk.test.lib.util.JarUtils;

import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import jdk.security.jarsigner.JarSigner;

public class NewSize7 {

    private static final String DEF_DIGEST_ALGO =
            JarSigner.Builder.getDefaultDigestAlgorithm();

    public static void main(String[] args) throws Exception {
        String common = "-storepass changeit -keypass changeit -keystore ks ";
        SecurityTools.keytool(common
                + "-keyalg rsa -genkeypair -alias me -dname CN=Me");
        Files.write(Path.of("ns7.txt"), new byte[0]);
        JarUtils.createJarFile(Path.of("ns7.jar"), Path.of("."),
                Path.of("ns7.txt"));
        SecurityTools.jarsigner(common + "ns7.jar me");

        try (JarFile jf = new JarFile("ns7.jar")) {
            try (InputStream is = jf.getInputStream(
                    jf.getEntry("META-INF/MANIFEST.MF"))) {
                Asserts.assertTrue(new Manifest(is).getAttributes("ns7.txt")
                        .keySet().stream()
                        .anyMatch(s -> s.toString().contains(DEF_DIGEST_ALGO)));
            }
            try (InputStream is = jf.getInputStream(
                    jf.getEntry("META-INF/ME.SF"))) {
                Asserts.assertTrue(new Manifest(is).getAttributes("ns7.txt")
                        .keySet().stream()
                        .anyMatch(s -> s.toString().contains(DEF_DIGEST_ALGO)));
            }
        }
    }
}
